@@ -47,7 +47,7 @@ TEMPLATES = {
 
             [tool.slap.test]
             check = "slap check"
-            mypy = "mypy src/"
+            mypy = "dmypy run src/"
             pytest = "pytest tests/ -vv"
             black = "black --check src/ tests/"
             isort = "isort --check-only src/ tests/"
@@ -57,6 +57,7 @@ TEMPLATES = {
             fmt = "black src/ tests/ && isort src/ tests/"
 
             [tool.mypy]
+            python_version = "3.6"
             explicit_package_bases = true
             mypy_path = ["src"]
             namespace_packages = true
@@ -72,7 +73,9 @@ TEMPLATES = {
             profile = "black"
             line_length = 120
             combine_as_imports = true
-            indent = "  "
+
+            [tool.black]
+            line-length = 120
         """,
         "LICENSE": "",
         "readme.md": """
@@ -82,14 +85,6 @@ TEMPLATES = {
         ".flake8": """
             [flake8]
             max-line-length = 120
-            ignore=
-            E111, # Indentation is not a multiple of four
-            E114, # Indentation is not a multiple of four (comment)
-            E121, # continuation line under-indented for hanging indent
-            E127, # continuation line over-indented for visual indent
-            E128, # continuation line under-indented for visual indent
-            W503, # line break before binary operator
-            W504, # line break after binary operator
         """,
         ".gitignore": """
             /.vscode
